{% load form_tags %}

<form method="POST" action="{{ action }}">

  {{ errors }}
  {% control field "True" "" "" %}

  <input type="hidden" name="field" value="{{ field.name }}" />

  <div class="btn-group">
    <button type="submit" class="btn btn-primary">Opslaan</button>
    <button type="cancel" class="btn cancel">Annuleren</button>
  </div>
</form> 

