<h3>{{ form.labels.header }}</h3>

<form method="POST" action="{{ action }}">
  {{ form }}
  <div class="btn-group">
    <button type="submit" class="btn btn-primary">
      {{ form.labels.submit|default:'Opslaan' }}
    </button>
    <button type="cancel" class="btn cancel">
      {{ form.labels.cancel|default:'Annuleren' }}
    </button>
  </div>
</form> 
